aboutsummaryrefslogtreecommitdiffstats
path: root/include/net/mac80211.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/net/mac80211.h')
-rw-r--r--include/net/mac80211.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/net/mac80211.h b/include/net/mac80211.h
index 28e66cdae3ec..8907338d52b5 100644
--- a/include/net/mac80211.h
+++ b/include/net/mac80211.h
@@ -3939,14 +3939,14 @@ struct ieee80211_prep_tx_info {
* twt structure.
* @twt_teardown_request: Update the hw with TWT teardown request received
* from the peer.
* @set_radar_offchan: Configure dedicated offchannel chain available for
* radar/CAC detection on some hw. This chain can't be used to transmit
* or receive frames and it is bounded to a running wdev.
* Offchannel radar/CAC detection allows to avoid the CAC downtime
* switching to a different channel during CAC detection on the selected
* radar channel.
* The caller is expected to set chandef pointer to NULL in order to
* disable offchannel CAC/radar detection.
* @net_fill_forward_path: Called from .ndo_fill_forward_path in order to
* resolve a path for hardware flow offloading
*/
@@ -4277,8 +4277,8 @@ struct ieee80211_ops {
struct ieee80211_twt_setup *twt);
void (*twt_teardown_request)(struct ieee80211_hw *hw,
struct ieee80211_sta *sta, u8 flowid);
- int (*set_radar_offchan)(struct ieee80211_hw *hw,
- struct cfg80211_chan_def *chandef);
+ int (*set_radar_background)(struct ieee80211_hw *hw,
+ struct cfg80211_chan_def *chandef);
int (*net_fill_forward_path)(struct ieee80211_hw *hw,
struct ieee80211_vif *vif,
struct ieee80211_sta *sta,
@@ -3939,14 +3939,14 @@ struct ieee80211_prep_tx_info {
* @twt_teardown_request: Update the hw with TWT teardown request received
* from the peer.
- * @set_radar_offchan: Configure dedicated offchannel chain available for
+ * @set_radar_background: Configure dedicated offchannel chain available for
* radar/CAC detection on some hw. This chain can't be used to transmit
* or receive frames and it is bounded to a running wdev.
@@ -3939,14 +3939,14 @@ struct ieee80211_prep_tx_info {
* radar/CAC detection on some hw. This chain can't be used to transmit
* or receive frames and it is bounded to a running wdev.
- * Offchannel radar/CAC detection allows to avoid the CAC downtime
+ * Background radar/CAC detection allows to avoid the CAC downtime
* switching to a different channel during CAC detection on the selected
* radar channel.
@@ -3939,14 +3939,14 @@ struct ieee80211_prep_tx_info {
* radar channel.
* The caller is expected to set chandef pointer to NULL in order to
- * disable offchannel CAC/radar detection.
+ * disable background CAC/radar detection.
* @net_fill_forward_path: Called from .ndo_fill_forward_path in order to
* resolve a path for hardware flow offloading